@@ -3,7 +3,7 @@ package Labyrinth;
 use warnings;
 use strict;
 
-our $VERSION = '5.21';
+our $VERSION = '5.22';
 
 =head1 NAME
 
@@ -103,7 +103,7 @@ sub run {
         UnPublish();                    # Start a fresh slate
         LoadSettings($file);            # Load All Global Settings
 
-        die $tvars{errmess} if($tvars{errcode} eq 'ERROR');
+        die $tvars{errmess} if($tvars{errcode} && $tvars{errcode} eq 'ERROR');
 
         MailSet(mailsend => $settings{mailsend}, logdir => $settings{logdir});
 
