@@ -4,7 +4,7 @@ use warnings;
 use strict;
 
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT @EXPORT_OK);
-$VERSION = '5.21';
+$VERSION = '5.22';
 
 =head1 NAME
 
@@ -31,7 +31,6 @@ and the functions are generic.
 All by default.
 
   use Labyrinth::Globals qw(:all);          # all methods
-  use Labyrinth::Globals qw(:default);      # barebones methods
 
 =cut
 
@@ -46,15 +45,11 @@ require Exporter;
         LoadAll LoadSettings LoadRules ParseParams
         DBConnect dbh
         ScriptPath ScriptFile
-    ) ],
-    'default' => [ qw(
-        dbh
-        ScriptPath ScriptFile
     ) ]
 );
 
 @EXPORT_OK  = ( @{$EXPORT_TAGS{'all'}} );
-@EXPORT     = ( @{$EXPORT_TAGS{'default'}} );
+@EXPORT     = ( @{$EXPORT_TAGS{'all'}} );
 
 # -------------------------------------
 # Library Modules
